from peak_utility.enumeration.parsing_enum import ParsingEnum  # type: ignore


class GoingDescription(ParsingEnum):
    """
    A parent enumeration for more specific going descriptions. Not intended to be instantiated directly.

    """

    pass
